==> phoenix-starter-bpmn-0.1.1.1-20240521.035918-1-sources.jar: com/elitesland/cbpl/bpmn/data/vo/resp/TaskDefinePagingVO.java <==
package com.elitesland.cbpl.bpmn.data.vo.resp;

import cn.hutool.core.util.StrUtil;
import com.elitesland.cbpl.bpmn.domain.TaskStatus;
import com.elitesland.cbpl.scheduling.domain.DeletionStrategy;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import java.io.Serializable;
import java.time.LocalDateTime;

/**
 * 任务流程 - 定义表
 *
 * @author eric.hao
 * @since 2024/05/09
 */
@Data
@ApiModel("任务流程 - 定义表")
public class TaskDefinePagingVO implements Serializable {

	private static final long serialVersionUID = 2940693185243307374L;

	@ApiModelProperty(value = "记录唯一ID")
	private Long id;

	@ApiModelProperty(value = "任务编码")
	private String taskCode;

	@ApiModelProperty(value = "任务名称")
	private String taskName;

	@ApiModelProperty(value = "任务类型：常规(规则)流程、接口调度流程、审批流程、业务流程")
	private String taskType;

	@ApiModelProperty(value = "状态：0禁用；1启用；")
	private Integer status;

	@JsonProperty
	public String getStatusName() {
		return TaskStatus.fromCode(status);
	}

	@ApiModelProperty(value = "实例删除策略")
	private String deletionStrategy;

	public String getDeletionStrategy() {
		return StrUtil.blankToDefault(deletionStrategy, DeletionStrategy.NO_DELETION.getDays());
	}

	@ApiModelProperty(value = "实例删除策略中文")
	@JsonProperty
	public String getDeletionStrategyName() {
		return DeletionStrategy.fromDays(getDeletionStrategy());
	}

	@ApiModelProperty(value = "备注")
	private String remark;

	@ApiModelProperty(value = "记录创建者ID")
	private Long createUserId;

	@ApiModelProperty(value = "记录创建者")
	private String creator;

	@ApiModelProperty(value = "记录创建时间")
	private LocalDateTime createTime;

	@ApiModelProperty(value = "记录最后更新者ID")
	private Long modifyUserId;

	@ApiModelProperty(value = "记录最后更新者")
	private String updater;

	@ApiModelProperty(value = "记录最后更新时间")
	private LocalDateTime modifyTime;
}

==> phoenix-starter-bpmn-0.1.1.15-20240603.034107-1-sources.jar: com/elitesland/cbpl/bpmn/data/vo/resp/TaskDefinePagingVO.java <==
package com.elitesland.cbpl.bpmn.data.vo.resp;

import cn.hutool.core.util.StrUtil;
import com.elitesland.cbpl.common.constant.ActiveStatus;
import com.elitesland.cbpl.scheduling.constant.DeletionStrategy;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import java.io.Serializable;
import java.time.LocalDateTime;

/**
 * 任务流程 - 定义表
 *
 * @author eric.hao
 * @since 2024/05/09
 */
@Data
@ApiModel("任务流程 - 定义表")
public class TaskDefinePagingVO implements Serializable {

	private static final long serialVersionUID = 2940693185243307374L;

	@ApiModelProperty(value = "记录唯一ID")
	private Long id;

	@ApiModelProperty(value = "任务编码")
	private String taskCode;

	@ApiModelProperty(value = "任务名称")
	private String taskName;

	@ApiModelProperty(value = "任务类型：常规(规则)流程、接口调度流程、审批流程、业务流程")
	private String taskType;

	@ApiModelProperty(value = "状态：0禁用；1启用；")
	private Integer status;

	@JsonProperty
	public String getStatusName() {
		return ActiveStatus.fromCode(status);
	}

	@ApiModelProperty(value = "实例删除策略")
	private String deletionStrategy;

	public String getDeletionStrategy() {
		return StrUtil.blankToDefault(deletionStrategy, DeletionStrategy.NO_DELETION.getDays());
	}

	@ApiModelProperty(value = "实例删除策略中文")
	@JsonProperty
	public String getDeletionStrategyName() {
		return DeletionStrategy.fromDays(getDeletionStrategy());
	}

	@ApiModelProperty(value = "备注")
	private String remark;

	@ApiModelProperty(value = "记录创建者ID")
	private Long createUserId;

	@ApiModelProperty(value = "记录创建者")
	private String creator;

	@ApiModelProperty(value = "记录创建时间")
	private LocalDateTime createTime;

	@ApiModelProperty(value = "记录最后更新者ID")
	private Long modifyUserId;

	@ApiModelProperty(value = "记录最后更新者")
	private String updater;

	@ApiModelProperty(value = "记录最后更新时间")
	private LocalDateTime modifyTime;
}
